@@ -1,6 +1,6 @@
 /* -*- mode:C; c-file-style: "bsd" -*- */
 /*
- * Copyright (c) 2008-2012 Yubico AB
+ * Copyright (c) 2008-2013 Yubico AB
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -72,6 +72,13 @@ int ykp_free_ndef(YK_NDEF *ndef);
 int ykp_construct_ndef_uri(YK_NDEF *ndef, const char *uri);
 int ykp_construct_ndef_text(YK_NDEF *ndef, const char *text, const char *lang, bool isutf16);
 int ykp_set_ndef_access_code(YK_NDEF *ndef, unsigned char *access_code);
+int ykp_ndef_as_text(YK_NDEF *ndef, char *text, size_t len);
+
+YK_DEVICE_CONFIG *ykp_alloc_device_config(void);
+int ykp_free_device_config(YK_DEVICE_CONFIG *device_config);
+int ykp_set_device_mode(YK_DEVICE_CONFIG *device_config, unsigned char mode);
+int ykp_set_device_chalresp_timeout(YK_DEVICE_CONFIG *device_config, unsigned char timeout);
+int ykp_set_device_autoeject_time(YK_DEVICE_CONFIG *device_config, unsigned short eject_time);
 
 int ykp_set_access_code(YKP_CONFIG *cfg, unsigned char *access_code, size_t len);
 int ykp_set_fixed(YKP_CONFIG *cfg, unsigned char *fixed, size_t len);
@@ -115,6 +122,7 @@ int ykp_set_extflag_USE_NUMERIC_KEYPAD (YKP_CONFIG *cfg, bool state);
 int ykp_set_extflag_FAST_TRIG (YKP_CONFIG *cfg, bool state);
 int ykp_set_extflag_ALLOW_UPDATE (YKP_CONFIG *cfg, bool state);
 int ykp_set_extflag_DORMANT (YKP_CONFIG *cfg, bool state);
+int ykp_set_extflag_LED_INV (YKP_CONFIG *cfg, bool state);
 
 int ykp_write_config(const YKP_CONFIG *cfg,
 		     int (*writer)(const char *buf, size_t count,
@@ -129,6 +137,12 @@ YK_CONFIG *ykp_core_config(YKP_CONFIG *cfg);
 int ykp_command(YKP_CONFIG *cfg);
 int ykp_config_num(YKP_CONFIG *cfg);
 
+int ykp_export_config(const YKP_CONFIG *cfg, char *buf, size_t len, int format);
+int ykp_import_config(YKP_CONFIG *cfg, const char *buf, size_t len, int format);
+
+#define YKP_FORMAT_LEGACY	0x01
+#define YKP_FORMAT_YCFG		0x02
+
 extern int * _ykp_errno_location(void);
 #define ykp_errno (*_ykp_errno_location())
 const char *ykp_strerror(int errnum);
